@@ -1,6 +1,4 @@
-
-import argparse
-from .cli import CLI
+from deep_translator.cli import CLI
 
 
 def main():
